==> hgug4100a.db_2.2.5.tar.gz: hgug4100a.db/man/hgug4100a_dbconn.Rd <==
\name{hgug4100a_dbconn}

\alias{hgug4100a_dbconn}
\alias{hgug4100a_dbfile}
\alias{hgug4100a_dbschema}
\alias{hgug4100a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgug4100a_dbconn()
  hgug4100a_dbfile()
  hgug4100a_dbschema(file="", show.indices=FALSE)
  hgug4100a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgug4100a_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hgug4100a_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hgug4100a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgug4100a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgug4100a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgug4100a_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hgug4100a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgug4100a_dbschema}: none (invisible \code{NULL}).

  \code{hgug4100a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgug4100a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgug4100a_dbconn() was created with:
  dbConnect(SQLite(), dbname=hgug4100a_dbfile(), cache_size=64000, synchronous=0)

  hgug4100a_dbschema()

  hgug4100a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hgug4100a.db_2.14.0.tar.gz: hgug4100a.db/man/hgug4100a_dbconn.Rd <==

\name{hgug4100a_dbconn}

\alias{hgug4100a_dbconn}
\alias{hgug4100a_dbfile}
\alias{hgug4100a_dbschema}
\alias{hgug4100a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgug4100a_dbconn()
  hgug4100a_dbfile()
  hgug4100a_dbschema(file="", show.indices=FALSE)
  hgug4100a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgug4100a_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hgug4100a_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hgug4100a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgug4100a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgug4100a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgug4100a_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hgug4100a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgug4100a_dbschema}: none (invisible \code{NULL}).

  \code{hgug4100a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgug4100a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgug4100a_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hgug4100a_dbfile(), cache_size=64000,
  synchronous=0)

  hgug4100a_dbschema()

  hgug4100a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
